@@ -11,7 +11,7 @@
  * Copyright (C) 2009-2012 by Andi Clemens <andi dot clemens at gmail dot com>
  * Copyright (C)      2013 by Michael G. Hansen <mike at mghansen dot de>
  * Copyright (C) 2014-2015 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
- * Copyright (C) 2002-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -67,12 +67,10 @@ DigikamApp::DigikamApp()
         d->splashScreen = new DSplashScreen();
         d->splashScreen->show();
     }
-    else
-    {
-        // Windows need here QCoreApplication::processEvents().
 
-        qApp->processEvents();
-    }
+    // We need here QCoreApplication::processEvents().
+
+    qApp->processEvents();
 
     if (d->splashScreen)
     {
@@ -165,6 +163,27 @@ DigikamApp::DigikamApp()
 
     d->validIccPath = SetupICC::iccRepositoryIsValid();
 
+    // Clean up database if enabled in the settings
+
+    if (ApplicationSettings::instance()->getCleanAtStart() &&
+        CollectionScanner::databaseInitialScanDone())
+    {
+        if (d->splashScreen)
+        {
+            d->splashScreen->setMessage(i18n("Clean up Database..."));
+        }
+
+        QEventLoop loop;
+
+        DbCleaner* const tool = new DbCleaner(false, false);
+
+        connect(tool, SIGNAL(signalComplete()),
+                &loop, SLOT(quit()));
+
+        tool->start();
+        loop.exec();
+    }
+
     // Read albums from database
 
     if (d->splashScreen)
@@ -341,22 +360,25 @@ void DigikamApp::show()
 
     // Init album icon view zoom factor.
 
-    slotThumbSizeChanged(ApplicationSettings::instance()->getDefaultIconSize());
-    slotZoomSliderChanged(ApplicationSettings::instance()->getDefaultIconSize());
+    ApplicationSettings* const settings = ApplicationSettings::instance();
+
+    slotThumbSizeChanged(settings->getDefaultIconSize());
+    slotZoomSliderChanged(settings->getDefaultIconSize());
     d->autoShowZoomToolTip = true;
 
     // Enable finished the collection scan as deferred process
 
-    if (ApplicationSettings::instance()->getScanAtStart() ||
+    if (settings->getScanAtStart()                  ||
         !CollectionScanner::databaseInitialScanDone())
     {
         NewItemsFinder* const tool = new NewItemsFinder(NewItemsFinder::ScanDeferredFiles);
-        QTimer::singleShot(1000, tool, SLOT(start()));
-    }
 
-    if (ApplicationSettings::instance()->getCleanAtStart())
-    {
-        DbCleaner* const tool = new DbCleaner(false, false);
+        if (settings->getDetectFacesInNewImages())
+        {
+            connect(tool, SIGNAL(signalComplete()),
+                    this, SLOT(slotDetectFaces()));
+        }
+
         QTimer::singleShot(1000, tool, SLOT(start()));
     }
 }
@@ -595,20 +617,21 @@ void DigikamApp::slotImageSelected(const ItemInfoList& selection, const ItemInfo
         {
             if (numImagesWithGrouped == numImagesWithoutGrouped)
             {
-                statusBarSelectionText
-                        = i18np("No item selected (%1 item)", "No item selected (%1 items)",
-                                numImagesWithoutGrouped);
+                statusBarSelectionText = i18np("No item selected (%1 item)",
+                                               "No item selected (%1 items)",
+                                               numImagesWithoutGrouped);
                 break;
             }
 
-            statusBarSelectionText
-                        = i18np("No item selected (%1 [%2] item)",
-                                "No item selected (%1 [%2] items)",
-                                numImagesWithoutGrouped, numImagesWithGrouped);
-            statusBarSelectionToolTip
-                        = i18np("No item selected (%1 item. With grouped items: %2)",
-                                "No item selected (%1 items. With grouped items: %2)",
-                                numImagesWithoutGrouped, numImagesWithGrouped);
+            statusBarSelectionText    = i18np("No item selected (%1 [%2] item)",
+                                              "No item selected (%1 [%2] items)",
+                                              numImagesWithoutGrouped,
+                                              numImagesWithGrouped);
+
+            statusBarSelectionToolTip = i18np("No item selected (%1 item. With grouped items: %2)",
+                                              "No item selected (%1 items. With grouped items: %2)",
+                                              numImagesWithoutGrouped,
+                                              numImagesWithGrouped);
             break;
         }
 
@@ -616,10 +639,12 @@ void DigikamApp::slotImageSelected(const ItemInfoList& selection, const ItemInfo
         {
             if (numImagesWithGrouped == numImagesWithoutGrouped)
             {
-                statusBarSelectionText = i18n("%1/%2 items selected (%3/%4)",
-                                              selection.count(), numImagesWithoutGrouped,
-                                              ItemPropertiesTab::humanReadableBytesCount(selectionFileSize),
-                                              ItemPropertiesTab::humanReadableBytesCount(listAllFileSize));
+                statusBarSelectionText = i18np("1/%2 item selected (%3/%4)",
+                                               "%1/%2 items selected (%3/%4)",
+                                               selection.count(),
+                                               numImagesWithoutGrouped,
+                                               ItemPropertiesTab::humanReadableBytesCount(selectionFileSize),
+                                               ItemPropertiesTab::humanReadableBytesCount(listAllFileSize));
                 break;
             }
 
@@ -627,28 +652,37 @@ void DigikamApp::slotImageSelected(const ItemInfoList& selection, const ItemInfo
             {
                 if (selection.count() == selectionWithoutGrouped.count())
                 {
-                    statusBarSelectionText
-                            = i18n("%1/%2 [%3] items selected (%4/%5)", selectionWithoutGrouped.count(),
-                                   numImagesWithoutGrouped, numImagesWithGrouped,
-                                   ItemPropertiesTab::humanReadableBytesCount(selectionFileSize),
-                                   ItemPropertiesTab::humanReadableBytesCount(listAllFileSize));
-                    statusBarSelectionToolTip
-                            = i18n("%1/%2 items selected. Total with grouped items: %3",
-                                   selectionWithoutGrouped.count(), numImagesWithoutGrouped,
-                                   numImagesWithGrouped);
+                    statusBarSelectionText    = i18np("1/%2 [%3] item selected (%4/%5)",
+                                                      "%1/%2 [%3] items selected (%4/%5)",
+                                                      selectionWithoutGrouped.count(),
+                                                      numImagesWithoutGrouped,
+                                                      numImagesWithGrouped,
+                                                      ItemPropertiesTab::humanReadableBytesCount(selectionFileSize),
+                                                      ItemPropertiesTab::humanReadableBytesCount(listAllFileSize));
+
+                    statusBarSelectionToolTip = i18np("1/%2 item selected. Total with grouped items: %3",
+                                                      "%1/%2 items selected. Total with grouped items: %3",
+                                                      selectionWithoutGrouped.count(),
+                                                      numImagesWithoutGrouped,
+                                                      numImagesWithGrouped);
                 }
                 else
                 {
-                    statusBarSelectionText
-                            = i18n("%1/%2 [%3/%4] items selected (%5/%6)",
-                                   selectionWithoutGrouped.count(), numImagesWithoutGrouped,
-                                   selection.count(), numImagesWithGrouped,
-                                   ItemPropertiesTab::humanReadableBytesCount(selectionFileSize),
-                                   ItemPropertiesTab::humanReadableBytesCount(listAllFileSize));
-                    statusBarSelectionToolTip
-                            = i18n("%1/%2 items selected. With grouped items: %3/%4",
-                                   selectionWithoutGrouped.count(), numImagesWithoutGrouped,
-                                   selection.count(), numImagesWithGrouped);
+                    statusBarSelectionText    = i18np("1/%2 [%3/%4] item selected (%5/%6)",
+                                                      "%1/%2 [%3/%4] items selected (%5/%6)",
+                                                      selectionWithoutGrouped.count(),
+                                                      numImagesWithoutGrouped,
+                                                      selection.count(),
+                                                      numImagesWithGrouped,
+                                                      ItemPropertiesTab::humanReadableBytesCount(selectionFileSize),
+                                                      ItemPropertiesTab::humanReadableBytesCount(listAllFileSize));
+
+                    statusBarSelectionToolTip = i18np("1/%2 item selected. With grouped items: %3/%4",
+                                                      "%1/%2 items selected. With grouped items: %3/%4",
+                                                      selectionWithoutGrouped.count(),
+                                                      numImagesWithoutGrouped,
+                                                      selection.count(),
+                                                      numImagesWithGrouped);
                 }
 
                 break;
@@ -1088,6 +1122,8 @@ void DigikamApp::slotColorManagementOptionsChanged()
 {
     ICCSettingsContainer settings = IccSettings::instance()->settings();
 
+    ThumbnailLoadThread::setDisplayingWidget(this);
+
     d->viewCMViewAction->blockSignals(true);
     d->viewCMViewAction->setEnabled(settings.enableCM);
     d->viewCMViewAction->setChecked(settings.useManagedPreviews);
