@@ -7,7 +7,7 @@
  * Description : database settings widget
  *
  * Copyright (C) 2009-2010 by Holger Foerster <Hamsi2k at freenet dot de>
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -100,14 +100,16 @@ void DatabaseSettingsWidget::setupMainArea()
     // --------------------------------------------------------
 
     d->dbPathLabel = new QLabel(i18n("<p>Set here the location where the database files will be stored on your system. "
-                                     "There are three databases: one for all collections properties, "
+                                     "There are four databases: "
+                                     "one for all collections properties, "
                                      "one to store compressed thumbnails, "
-                                     "and one to store faces recognition metadata.<br/>"
+                                     "one to store faces recognition metadata, "
+                                     "and one to store similarity finguerprints.<br/>"
                                      "Write access is required to be able to edit image properties.</p>"
                                      "<p>Databases are digiKam core engines. Take care to use a place hosted by fast "
-                                     "hardware (as SSD) with enough free space especially for thumbnails database.</p>"
+                                     "hardware (eg. SSD or NVMe) with enough free space especially for thumbnails database.</p>"
                                      "<p>Note: a remote file system such as NFS, cannot be used here. "
-                                     "For performance reasons, it is also recommended not to use removable media.</p>"
+                                     "For performance reasons, it is also recommended not to use network storage media.</p>"
                                      "<p></p>"), dbConfigBox);
     d->dbPathLabel->setWordWrap(true);
     d->dbPathEdit  = new DFileSelector(dbConfigBox);
@@ -159,7 +161,7 @@ void DatabaseSettingsWidget::setupMainArea()
 #ifdef Q_OS_WIN
 
     d->dbBinariesWidget->addDirectory(QLatin1String("C:/Program Files/MariaDB 10.5/bin"));
-    d->dbBinariesWidget->addDirectory(QLatin1String("C:/Program Files (x86/MariaDB 10.5/bin"));
+    d->dbBinariesWidget->addDirectory(QLatin1String("C:/Program Files (x86)/MariaDB 10.5/bin"));
 
 #endif
 
@@ -512,8 +514,8 @@ void DatabaseSettingsWidget::slotUpdateSqlInit()
                                .arg(d->userName->text())
                                .arg(d->hostName->text());
 
-    sql += QString::fromLatin1("CREATE DATABASE %1;<br>"
-                               "GRANT ALL PRIVILEGES ON %2.* TO \'%3\'@\'%4\';<br>")
+    sql += QString::fromLatin1("CREATE DATABASE `%1`;<br>"
+                               "GRANT ALL PRIVILEGES ON `%2`.* TO \'%3\'@\'%4\';<br>")
                                .arg(d->dbNameCore->text())
                                .arg(d->dbNameCore->text())
                                .arg(d->userName->text())
@@ -521,8 +523,8 @@ void DatabaseSettingsWidget::slotUpdateSqlInit()
 
     if (isNotEqualToThumbName(d->dbNameCore->text()))
     {
-        sql += QString::fromLatin1("CREATE DATABASE %1;<br>"
-                                   "GRANT ALL PRIVILEGES ON %2.* TO \'%3\'@\'%4\';<br>")
+        sql += QString::fromLatin1("CREATE DATABASE `%1`;<br>"
+                                   "GRANT ALL PRIVILEGES ON `%2`.* TO \'%3\'@\'%4\';<br>")
                                    .arg(d->dbNameThumbs->fileDlgPath())
                                    .arg(d->dbNameThumbs->fileDlgPath())
                                    .arg(d->userName->text())
@@ -532,8 +534,8 @@ void DatabaseSettingsWidget::slotUpdateSqlInit()
     if (isNotEqualToThumbName(d->dbNameFace->text())   &&
         (d->dbNameFace->text() != d->dbNameCore->text()))
     {
-        sql += QString::fromLatin1("CREATE DATABASE %1;<br>"
-                                   "GRANT ALL PRIVILEGES ON %2.* TO \'%3\'@\'%4\';<br>")
+        sql += QString::fromLatin1("CREATE DATABASE `%1`;<br>"
+                                   "GRANT ALL PRIVILEGES ON `%2`.* TO \'%3\'@\'%4\';<br>")
                                    .arg(d->dbNameFace->text())
                                    .arg(d->dbNameFace->text())
                                    .arg(d->userName->text())
@@ -544,8 +546,8 @@ void DatabaseSettingsWidget::slotUpdateSqlInit()
         (d->dbNameSimilarity->text() != d->dbNameCore->text()) &&
         (d->dbNameSimilarity->text() != d->dbNameFace->text()))
     {
-        sql += QString::fromLatin1("CREATE DATABASE %1;<br>"
-                                   "GRANT ALL PRIVILEGES ON %2.* TO \'%3\'@\'%4\';<br>")
+        sql += QString::fromLatin1("CREATE DATABASE `%1`;<br>"
+                                   "GRANT ALL PRIVILEGES ON `%2`.* TO \'%3\'@\'%4\';<br>")
                                    .arg(d->dbNameSimilarity->text())
                                    .arg(d->dbNameSimilarity->text())
                                    .arg(d->userName->text())
@@ -911,7 +913,7 @@ bool DatabaseSettingsWidget::checkDatabasePath()
 bool DatabaseSettingsWidget::isNotEqualToThumbName(const QString& name)
 {
     QFileInfo thumbDB(d->dbNameThumbs->fileDlgPath());
-    bool isDir = (thumbDB.exists() && thumbDB.isDir());
+    bool isDir = (thumbDB.exists() && thumbDB.isDir() && thumbDB.isAbsolute());
 
     return (!isDir && (d->dbNameThumbs->fileDlgPath() !=  name));
 }
