@@ -7,7 +7,7 @@
  * Description : Exiv2 library interface.
  *               Exif manipulation methods
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -423,10 +423,13 @@ bool MetaEngine::getExifTagRational(const char* exifTagName, long int& num, long
 
         if (it != exifData.end())
         {
-            num = (*it).toRational(component).first;
-            den = (*it).toRational(component).second;
+            if ((*it).count())
+            {
+                num = (*it).toRational(component).first;
+                den = (*it).toRational(component).second;
 
-            return true;
+                return true;
+            }
         }
     }
     catch (Exiv2::AnyError& e)
@@ -983,6 +986,12 @@ QImage MetaEngine::getExifThumbnail(bool fixOrientation) const
     {
         Exiv2::ExifThumbC thumb(d->exifMetadata());
         Exiv2::DataBuf const c1 = thumb.copy();
+
+        if (c1.size_ == 0)
+        {
+            return thumbnail;
+        }
+
         thumbnail.loadFromData(c1.pData_, c1.size_);
 
         if (!thumbnail.isNull())
@@ -1225,7 +1234,7 @@ MetaEngine::MetaDataMap MetaEngine::getExifTagsDataList(const QStringList& exifK
                 // NOTE: special cases to render contents of these GPS info tags. See bug #435317.
                 // Check value byte size, otherwise Exiv2 crashes in the toRational() function.
 
-                if ((*md).size())
+                if ((*md).count())
                 {
                     num  = (*md).toRational().first;
                     den  = (*md).toRational().second;
@@ -1239,7 +1248,7 @@ MetaEngine::MetaDataMap MetaEngine::getExifTagsDataList(const QStringList& exifK
                 // NOTE: special cases to render contents of these GPS info tags. See bug #435317.
                 // Check value byte size, otherwise Exiv2 crashes in the toRational() function.
 
-                if ((*md).size())
+                if ((*md).count())
                 {
                     num  = (*md).toRational().first;
                     den  = (*md).toRational().second;
