@@ -7,7 +7,7 @@
  * Description : Color management setup tab.
  *
  * Copyright (C) 2005-2007 by F.J. Cruz <fj dot cruz at supercable dot es>
- * Copyright (C) 2005-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2009-2012 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
@@ -901,8 +901,9 @@ void SetupICC::slotShowDefaultSearchPaths()
 
     QString text = i18n("On Windows, the default search paths include "
                         "<ul>"
-                        "<li>%1/Windows/Spool/Drivers/Color/</li>"   // For Win2K and WinXP
-                        "<li>%2/Windows/Color/</li>"                 // For Win98 and WinMe
+                        "<li>%1/Windows/System32/spool/drivers/color/</li>"   // For Win10 and Win7
+                        "<li>%1/Windows/Spool/Drivers/Color/</li>"            // For Win2K and WinXP
+                        "<li>%2/Windows/Color/</li>"                          // For Win98 and WinMe
                         "</ul>"
                         "On your system, currently these paths exist and are scanned:"
                         "<ul>"
@@ -914,13 +915,13 @@ void SetupICC::slotShowDefaultSearchPaths()
 
 #elif defined (Q_OS_MACOS)
 
-    QString text = i18n("On Mac OS X, the default search paths include "
+    QString text = i18n("On macOS, the default search paths include "
                         "<ul>"
                         "<li>/System/Library/ColorSync/Profiles</li>"
                         "<li>/Library/ColorSync/Profiles</li>"
                         "<li>~/Library/ColorSync/Profiles</li>"
                         "<li>/opt/local/share/color/icc</li>"
-                        "<li>%1/share/color/icc</li>"
+                        "<li>%1/Contents/Resources/digikam/profiles/</li>"
                         "<li>~/.local/share/color/icc/</li>"
                         "<li>~/.local/share/icc/</li>"
                         "<li>~/.color/icc/</li>"
@@ -931,6 +932,7 @@ void SetupICC::slotShowDefaultSearchPaths()
                         "</ul>",
                         macOSBundlePrefix(),
                         existingPaths);
+
 #else // Linux
 
     QString text = i18n("On Linux, the default search paths include "
