@@ -83,13 +83,13 @@ lib/plugins/digikam/generic/*.so \
 lib/plugins/digikam/editor/*.so \
 lib/plugins/digikam/dimg/*.so \
 lib/plugins/digikam/rawimport/*.so \
-lib/mariadb-10.5/bin/mysql \
-lib/mariadb-10.5/bin/mysqld \
-lib/mariadb-10.5/bin/my_print_defaults \
-lib/mariadb-10.5/bin/mysqladmin \
-lib/mariadb-10.5/bin/mysqltest \
-lib/mariadb-10.5/mysql/*.dylib \
-lib/mariadb-10.5/plugin/*.so \
+lib/mariadb$MARIADB_SUFFIX/bin/mysql \
+lib/mariadb$MARIADB_SUFFIX/bin/mysqld \
+lib/mariadb$MARIADB_SUFFIX/bin/my_print_defaults \
+lib/mariadb$MARIADB_SUFFIX/bin/mysqladmin \
+lib/mariadb$MARIADB_SUFFIX/bin/mysqltest \
+lib/mariadb$MARIADB_SUFFIX/mysql/*.dylib \
+lib/mariadb$MARIADB_SUFFIX/plugin/*.so \
 bin/kbuildsycoca5 \
 bin/solid-hardware5 \
 libexec/qt5/plugins/imageformats/*.dylib \
@@ -115,13 +115,13 @@ lib/libdigikam*.dSYM \
 lib/plugins \
 lib/libgphoto2 \
 lib/libgphoto2_port \
-lib/mariadb-10.5 \
+lib/mariadb$MARIADB_SUFFIX \
 lib/ImageMagick* \
-share/mariadb-10.5 \
+share/mariadb$MARIADB_SUFFIX \
 share/ImageMagick* \
 etc/xdg \
 etc/ImageMagick* \
-etc/mariadb-10.5 \
+etc/mariadb$MARIADB_SUFFIX \
 "
 
 #etc/sane.d \
@@ -545,12 +545,12 @@ for HPP in ${HEADERFILES[@]} ; do
 
 done
 
-rm -rfv $TEMPROOT/digikam.app/Contents/share/mariadb-10.5/mysql-test
-rm -rfv $TEMPROOT/digikam.app/Contents/share/mariadb-10.5/sql-bench
+rm -rfv $TEMPROOT/digikam.app/Contents/share/mariadb$MARIADB_SUFFIX/mysql-test
+rm -rfv $TEMPROOT/digikam.app/Contents/share/mariadb$MARIADB_SUFFIX/sql-bench
 
 echo -e "\n---------- Patch config and script files in bundle"
 
-MARIADBDIRS=(`find $TEMPROOT -type d -name "mariadb-10.5"`)
+MARIADBDIRS=(`find $TEMPROOT -type d -name "mariadb$MARIADB_SUFFIX"`)
 
 for DIR in ${MARIADBDIRS[@]} ; do
 
@@ -585,14 +585,29 @@ done
 #################################################################################################
 # See bug #436624: move mariadb share files at basedir (this must be done after patch operations)
 
-rsync -a "$TEMPROOT/digikam.app/Contents/share/mariadb-10.5" "$TEMPROOT/digikam.app/Contents/lib/mariadb-10.5/share/"
-rm -fr "$TEMPROOT/digikam.app/Contents/share/mariadb-10.5"
+rsync -a "$TEMPROOT/digikam.app/Contents/share/mariadb$MARIADB_SUFFIX" "$TEMPROOT/digikam.app/Contents/lib/mariadb$MARIADB_SUFFIX/share/"
+rm -fr "$TEMPROOT/digikam.app/Contents/share/mariadb$MARIADB_SUFFIX"
 
 # At run time, digiKam will check for mariadb folder-name without revision numbers.
 
-ln -sv "../../../../../digikam.app/Contents/lib/mariadb-10.5/share/mariadb-10.5" "$TEMPROOT/digikam.app/Contents/lib/mariadb-10.5/share/mariadb"
-ln -sv "../../../digikam.app/Contents/lib/mariadb-10.5"                          "$TEMPROOT/digikam.app/Contents/lib/mariadb"
-ln -sv "../../../digikam.app/Contents/etc/mariadb-10.5"                          "$TEMPROOT/digikam.app/Contents/etc/mariadb"
+ln -sv "../../../../../digikam.app/Contents/lib/mariadb$MARIADB_SUFFIX/share/mariadb$MARIADB_SUFFIX" "$TEMPROOT/digikam.app/Contents/lib/mariadb$MARIADB_SUFFIX/share/mariadb"
+ln -sv "../../../digikam.app/Contents/lib/mariadb$MARIADB_SUFFIX"                                    "$TEMPROOT/digikam.app/Contents/lib/mariadb"
+ln -sv "../../../digikam.app/Contents/etc/mariadb$MARIADB_SUFFIX"                                    "$TEMPROOT/digikam.app/Contents/etc/mariadb"
+
+#################################################################################################
+# Install ExifTool binary.
+
+cd $DOWNLOAD_DIR
+
+#if [ ! -f "$DOWNLOAD_DIR/Image-ExifTool.tar.gz" ] ; then
+    wget "https://files.kde.org/digikam/exiftool/Image-ExifTool.tar.gz" -O Image-ExifTool.tar.gz
+#fi
+
+tar -xvf "$DOWNLOAD_DIR/Image-ExifTool.tar.gz" -C "$TEMPROOT/digikam.app/Contents/bin"
+ln -s "$TEMPROOT/digikam.app/Contents/bin/Image-ExifTool*" "$TEMPROOT/digikam.app/Contents/bin/Image-ExifTool"
+
+cd "$TEMPROOT/digikam.app/Contents/bin"
+ln -sv "./Image-ExifTool/exiftool" exiftool
 
 #################################################################################################
 # Build PKG file
@@ -611,7 +626,7 @@ else
 
     # with official release version, disable upload to KDE server, as this break check for new version function.
     echo -e "Official release version detected, upload is disabled.\n"
-    DK_UPLOAD = 0
+    DK_UPLOAD=0
 
 fi
 
