@@ -45,7 +45,7 @@ if [[ $ARCH_TARGET = "x86_64" ]] ; then
     # 10.6  : SnowLeopard  : untested : ???
     #
     # Older values cannot be set as it do not support x86_64.
-    OSX_MIN_TARGET="10.13"
+    OSX_MIN_TARGET="10.15"
 
 elif [[ $ARCH_TARGET = "arm64" ]] ; then
 
@@ -89,14 +89,25 @@ DK_URL="http://download.kde.org/stable/digikam"
 DK_BUILDTEMP=~/dktemp
 
 # KDE Application version.
-DK_KA_VERSION="22.04.3"
+DK_KA_VERSION="22.12.1"
 
 # KDE KF5 frameworks version.
-DK_KF5_VERSION="5.96"
+DK_KF5_VERSION="5.102"
 
 # Qt version to use in bundle and provided by Macports.
 DK_QTVERSION="5.15"
 
+# Mariadb version to install for Qt QSL plugin.
+# Left empty to use current 5.x from Macports
+DK_MARIADB_VERSION=""
+#DK_MARIADB_VERSION="10.5"
+
+if [[ ! -z "$DK_MARIADB_VERSION" ]] ; then
+    MP_MARIADB_VARIANT="+mariadb$DK_MARIADB_VERSION"
+    MP_MARIADB_VARIANT=${MP_MARIADB_VARIANT//./_}
+    MARIADB_SUFFIX="-$DK_MARIADB_VERSION"
+fi
+
 # digiKam tag version from git. Official tarball do not include extra shared libraries.
 # The list of tags can be listed with this url: https://invent.kde.org/graphics/digikam/-/tags
 # If you want to package current implementation from git, use "master" as tag.
@@ -118,5 +129,5 @@ DK_SIGN=0
 
 # Upload automatically bundle to files.kde.org (pre-release only).
 DK_UPLOAD=1
-DK_UPLOADURL="digikam@deino.kde.org"
+DK_UPLOADURL="digikam@tinami.kde.org"
 DK_UPLOADDIR="/srv/archives/files/digikam/"
