@@ -7,11 +7,13 @@
 
 ########################################################################
 
+MXE_ROOT_DIR=/mnt/data
+
 # Absolute path where are downloaded all tarballs to compile.
-DOWNLOAD_DIR="`pwd`/temp.dwnld"
+DOWNLOAD_DIR="$MXE_ROOT_DIR/temp.dwnld"
 
 # Absolute path where are compiled all tarballs
-BUILDING_DIR="`pwd`/temp.build"
+BUILDING_DIR="$MXE_ROOT_DIR/temp.build"
 
 #-------------------------------------------------------------------------------------------
 
@@ -27,11 +29,11 @@ MXE_ARCHBITS=64
 if [[ $MXE_ARCHBITS == 32 ]]; then
     # Windows 32 bits shared
     MXE_BUILD_TARGETS="i686-w64-mingw32.shared"
-    MXE_BUILDROOT="`pwd`/build.win32"
+    MXE_BUILDROOT="$MXE_ROOT_DIR/build.win32"
 elif [[ $MXE_ARCHBITS == 64 ]]; then
     # Windows 64 bits shared
     MXE_BUILD_TARGETS="x86_64-w64-mingw32.shared"
-    MXE_BUILDROOT="`pwd`/build.win64"
+    MXE_BUILDROOT="$MXE_ROOT_DIR/build.win64"
 else
     echo "Unsupported or wrong target Windows architecture: $MXE_ARCHBITS bits."
     exit -1
@@ -63,13 +65,13 @@ DK_GITURL="git@invent.kde.org:graphics/digikam.git"
 DK_URL="http://download.kde.org/stable/digikam"
 
 # Location to build source code.
-DK_BUILDTEMP=~/dktemp
+DK_BUILDTEMP=$MXE_ROOT_DIR/dktemp
 
 # KDE Application version.
-DK_KA_VERSION="22.04.3"
+DK_KA_VERSION="22.12.1"
 
 # KDE KF5 frameworks version.
-DK_KF5_VERSION="5.96"
+DK_KF5_VERSION="5.102"
 
 # Qt version to use in bundle and provided by MXE.
 DK_QTVERSION="5.15"
@@ -92,5 +94,5 @@ DK_SIGN=0
 
 # Upload automatically bundle to files.kde.org (pre-release only).
 DK_UPLOAD=1
-DK_UPLOADURL="digikam@deino.kde.org"
+DK_UPLOADURL="digikam@tinami.kde.org"
 DK_UPLOADDIR="/srv/archives/files/digikam/"
